@@ -12,13 +12,14 @@
 from twisted.python import log
 from os.path import isfile
 
-from amon.dansguardian import dans_tools
-from amon.dansguardian.config import dans_status
+from amon.guardian import dans_tools
+from amon.guardian.config import dans_status
 
 from ead2.backend.actions.amon import amon_tools as t
 from ead2.backend.actions import tools
 from ead2.backend.actions.lib.widgets import main as M, form as F
 from ead2.backend.config.filenames import navigation_filters
+from ead2.backend.config.config import debug
 
 list_mime_filename = navigation_filters['list_mime']
 
@@ -324,10 +325,10 @@ def valid_opt_filters_form(form_result, zone):
                                   zone=zone_indices[zone])
 
     message = "La configuration du filtrage syntaxique a été modifiée."
-    if dans_tools.reload():
+    if dans_tools.restart():
         message += "\\nLe filtre a bien été rechargé."
     else:
-        log.err("Erreur au lancement de /etc/init.d/dansguardian reload(2) dans forms.py")
+        log.err("Erreur au lancement de service eole-guardian reload(2) dans forms.py")
     return dict(message=message)
 
 def valid_filtrage_form(form_result, zone):
@@ -339,7 +340,8 @@ def valid_filtrage_form(form_result, zone):
         status_f.close()
 
     resultat = tools.format_form_result(form_result)
-    log.msg(resultat)
+    if debug:
+        log.msg(resultat)
 
     status = resultat['dans']
     dans_tools.set_filtrage(zone_indices[zone], status)
@@ -356,10 +358,10 @@ s'effectue désormais sur l'intégralité de la page.".format(zone_msg[zone])
         message = "Le filtrage syntaxique de la navigation web sur \
 le {0} est désactivé.".format(zone_msg[zone])
 
-    if dans_tools.reload():
+    if dans_tools.restart():
         message += "\\nLe filtre a bien été rechargé."
     else:
-        log.err("Erreur au lancement de /etc/init.d/dansguardian reload(2) dans forms.py")
+        log.err("Erreur au lancement de service eole-guardian reload(2) dans forms.py")
     return dict(message=message)
 
 def valid_sitelist_form(form_result, zone, keyword):
@@ -368,11 +370,12 @@ def valid_sitelist_form(form_result, zone, keyword):
         à la liste des sites interdits/autorisés
     """
     resultat = tools.format_form_result(form_result, True)
-    log.msg("Ajout d'un site %s : %s" % (keyword, resultat['addsite']))
+    if debug:
+        log.msg("Ajout d'un site %s : %s" % (keyword, resultat['addsite']))
     site = t.format_url(resultat['addsite'])
 
     # caractères interdits dans les adresses à filter
-    for char in ('?', '=', '&', '%', '"', "'"):
+    for char in ('%', '"', "'"):
         if char in site:
             raise Exception("""Erreur :\\nLe caractère %s n'est pas autorisé dans les adresses""" % char)
 
@@ -407,13 +410,14 @@ def valid_sitelist_form(form_result, zone, keyword):
                     raise Exception("Veuillez supprimer ce site de %s \
 pour la politique %s." % (list_msg[antikeyword], policy))
                 policies_checked[index] = 1
-            log.msg("Les zones concernées : %d -> %s => %s" % (index,
+            if debug:
+                log.msg("Les zones concernées : %d -> %s => %s" % (index,
                                                               policy,
                                                       resultat[str(index)]))
     listed[site] = policies_checked
     dans_tools.save_site_list(listed, keyword, zone_indices[zone])
-    if not dans_tools.reload():
-        log.err("Erreur au lancement de /etc/init.d/dansguardian \
+    if not dans_tools.restart():
+        log.err("Erreur au lancement de service eole-guardian \
 reload(2) dans forms.py")
     return dict()
 
@@ -427,7 +431,8 @@ def valid_mod_list(data_names, data_table, zone, keyword):
     data_list = {}
     for data in datas:
         policies_checked = []
-        log.msg("data %s en %s"%(data, keyword))
+        if debug:
+            log.msg("data %s en %s"%(data, keyword))
 
         # variable pour tester si un site n'est pas présent
         # dans la liste opposée pour une politique
@@ -443,7 +448,8 @@ def valid_mod_list(data_names, data_table, zone, keyword):
 
         for index, policy in enumerate(dans_tools.columns_libelle):
             key = dans_tools.option_and_index_to_name(data, index)
-            log.msg("La politique %s : %s"%(policy, checked[key]))
+            if debug:
+                log.msg("La politique %s : %s"%(policy, checked[key]))
             if checked[key]:
                 #test si un site à autoriser
                 # pour une police n'est pas interdits (ou inverse)
@@ -459,8 +465,8 @@ def valid_mod_list(data_names, data_table, zone, keyword):
             data_list[data] = policies_checked
 
     dans_tools.save_site_list(data_list, keyword, zone_indices[zone])
-    if not dans_tools.reload():
-        log.err("Erreur au lancement de /etc/init.d/dansguardian \
+    if not dans_tools.restart():
+        log.err("Erreur au lancement de service eole-guardian \
 reload(2) dans forms.py")
     return dict()
 
@@ -470,7 +476,8 @@ def valid_extension_form(form_result, zone):
         à la liste d'extensions interdites
     """
     resultat = tools.format_form_result(form_result, True)
-    log.msg("Ajout d'une extension interdite : %s" % resultat['addextension'])
+    if debug:
+        log.msg("Ajout d'une extension interdite : %s" % resultat['addextension'])
     extension = t.format_ext(resultat['addextension'])
 
     forbidden_extensions = dans_tools.load_site_list('extension',
@@ -484,7 +491,8 @@ def valid_extension_form(form_result, zone):
         if resultat.has_key(str(index)):
             if resultat[str(index)]:
                 policies_checked[index] = 1
-            log.msg("Les zones concernées : %d -> %s => %s" % (index,
+            if debug:
+                log.msg("Les zones concernées : %d -> %s => %s" % (index,
                                                 policy,
                                                 resultat[str(index)]))
     forbidden_extensions[extension] = policies_checked
@@ -492,8 +500,8 @@ def valid_extension_form(form_result, zone):
     dans_tools.save_site_list(forbidden_extensions,
                               'extension',
                               zone_indices[zone])
-    if not dans_tools.reload():
-        log.err("Erreur au lancement de /etc/init.d/dansguardian \
+    if not dans_tools.restart():
+        log.err("Erreur au lancement de service eole-guardian \
 reload(2) dans forms.py")
     return dict()
 
@@ -504,7 +512,8 @@ def valid_mime_form(form_result, zone):
         à la liste de types mime interdits
     """
     resultat = tools.format_form_result(form_result, True)
-    log.msg("Ajout d'un type mime interdit : %s"%resultat['addmime'])
+    if debug:
+        log.msg("Ajout d'un type mime interdit : %s"%resultat['addmime'])
     mime = resultat['addmime']
 
     forbidden_mimes = dans_tools.load_site_list('mime',
@@ -518,14 +527,15 @@ def valid_mime_form(form_result, zone):
         if resultat.has_key(str(index)):
             if resultat[str(index)]:
                 policies_checked[index] = 1
-            log.msg("Les zones concernées : %d -> %s => %s"%(index,
+            if debug:
+                log.msg("Les zones concernées : %d -> %s => %s"%(index,
                                                policy,
                                                resultat[str(index)]))
     forbidden_mimes[mime] = policies_checked
     dans_tools.save_site_list(forbidden_mimes,
                               'mime',
                               zone_indices[zone])
-    if not dans_tools.reload():
-        log.err("Erreur au lancement de /etc/init.d/dansguardian \
+    if not dans_tools.restart():
+        log.err("Erreur au lancement de service eole-guardian \
 reload(2) dans forms.py")
     return dict()
